**Example 1: 添加域名**



Input: 

```
tccli live AddLiveDomain --cli-unfold-argument  \
    --DomainType 0 \
    --DomainName www.test.com
```

Output: 
```
{
    "Response": {
        "RequestId": "eac6b301-a322-493a-8e36-83b295459397"
    }
}
```

